@@ -214,7 +214,7 @@ function get_group_array($add_blank=true, $status="Active", $assigned_user="",$p
 			$query .= " WHERE groupid=?";
 			$params = array( $current_user->id);
 
-			if(count($current_user_groups) != 0) {
+			if(!empty($current_user_groups) && (count($current_user_groups) != 0)) {
 				$query .= " OR vtiger_groups.groupid in (".generateQuestionMarks($current_user_groups).")";
 				array_push($params, $current_user_groups);
 			}
@@ -222,7 +222,7 @@ function get_group_array($add_blank=true, $status="Active", $assigned_user="",$p
 			$query .= " union select vtiger_group2role.groupid as groupid,vtiger_groups.groupname as groupname from vtiger_group2role inner join vtiger_groups on vtiger_groups.groupid=vtiger_group2role.groupid inner join vtiger_role on vtiger_role.roleid=vtiger_group2role.roleid where vtiger_role.parentrole like ?";
 			array_push($params, $current_user_parent_role_seq."::%");
 
-			if(count($current_user_groups) != 0) {
+			if(!empty($current_user_groups) && (count($current_user_groups) != 0)) {
 				$query .= " union select vtiger_groups.groupid as groupid,vtiger_groups.groupname as groupname from vtiger_groups inner join vtiger_group2rs on vtiger_groups.groupid=vtiger_group2rs.groupid where vtiger_group2rs.roleandsubid in (".generateQuestionMarks($parent_roles).")";
 				array_push($params, $parent_roles);
 			}
@@ -334,7 +334,7 @@ function set_default_config(&$defaults)
  */
 function decide_to_html() {
 	global $doconvert, $inUTF8, $default_charset;
- 	$action = $_REQUEST['action']; 
+ 	$action = isset($_REQUEST['action']) ? $_REQUEST['action'] : ''; 
  		     
     $inUTF8 = (strtoupper($default_charset) == 'UTF-8'); 
 
@@ -1217,7 +1217,7 @@ function getAccessPickListValues($module)
 	$roleid = $current_user->roleid;
 	$subrole = getRoleSubordinates($roleid);
 
-	if(count($subrole)> 0)
+	if(!empty($subrole) && (count($subrole)> 0))
 {
 		$roleids = $subrole;
 		array_push($roleids, $roleid);
@@ -1230,7 +1230,7 @@ function getAccessPickListValues($module)
 	$temp_status = Array();
 	for($i=0;$i < $adb->num_rows($result);$i++)
 {
-		$fieldname = $adb->query_result($result,$i,"fieldname");
+		$fieldname = Vtiger_Util_Helper::validateStringForSql($adb->query_result($result,$i,"fieldname"));
 		$fieldlabel = $adb->query_result($result,$i,"fieldlabel");
 		$columnname = $adb->query_result($result,$i,"columnname");
 		$tabid = $adb->query_result($result,$i,"tabid");
@@ -1238,7 +1238,7 @@ function getAccessPickListValues($module)
 
 		$keyvalue = $columnname;
 		$fieldvalues = Array();
-		if (count($roleids) > 1)
+		if (!empty($roleids) && (count($roleids) > 1))
 	{
 			$mulsel="select distinct $fieldname from vtiger_$fieldname inner join vtiger_role2picklist on vtiger_role2picklist.picklistvalueid = vtiger_$fieldname.picklist_valueid where roleid in (\"". implode($roleids,"\",\"") ."\") and picklistid in (select picklistid from vtiger_$fieldname) order by sortid asc";
 	}
@@ -1247,7 +1247,7 @@ function getAccessPickListValues($module)
 			$mulsel="select distinct $fieldname from vtiger_$fieldname inner join vtiger_role2picklist on vtiger_role2picklist.picklistvalueid = vtiger_$fieldname.picklist_valueid where roleid ='".$roleid."' and picklistid in (select picklistid from vtiger_$fieldname) order by sortid asc";
 	}
 		if($fieldname != 'firstname')
-			$mulselresult = $adb->query($mulsel);
+			$mulselresult = $adb->pquery($mulsel, array());
 		for($j=0;$j < $adb->num_rows($mulselresult);$j++)
 		{
 			$fieldvalues[] = $adb->query_result($mulselresult,$j,$fieldname);
@@ -1376,7 +1376,7 @@ function transferProductCurrency($old_cur, $new_cur) {
 	for($i=0;$i<$numRows;$i++) {
 		$prod_ids[] = $adb->query_result($prod_res,$i,'productid');
 	}
-	if(count($prod_ids) > 0) {
+	if(!empty($prod_ids) && (count($prod_ids) > 0)) {
 		$prod_price_list = getPricesForProducts($new_cur,$prod_ids);
 
 		for($i=0;$i<count($prod_ids);$i++) {
@@ -1402,7 +1402,7 @@ function transferPriceBookCurrency($old_cur, $new_cur) {
 		$pb_ids[] = $adb->query_result($pb_res,$i,'pricebookid');
 }
 
-	if(count($pb_ids) > 0) {
+	if(!empty($pb_ids) && (count($pb_ids) > 0)) {
 		require_once('modules/PriceBooks/PriceBooks.php');
 
 		for($i=0;$i<count($pb_ids);$i++) {
@@ -1429,7 +1429,7 @@ function transferServicesCurrency($old_cur, $new_cur) {
     for ($i = 0; $i < $numRows; $i++) {
         $ser_ids[] = $adb->query_result($ser_res, $i, 'serviceid');
     }
-    if (count($ser_ids) > 0) {
+    if (!empty($ser_ids) && (count($ser_ids) > 0)) {
         $ser_price_list = getPricesForProducts($new_cur, $ser_ids, 'Services');
         for ($i = 0; $i < count($ser_ids); $i++) {
             $service_id = $ser_ids[$i];
@@ -1597,7 +1597,7 @@ function getRelationTables($module,$secmodule){
 				}
 			}
 	}else {
-		if(method_exists($primary_obj,setRelationTables)){
+		if(method_exists($primary_obj,'setRelationTables')){
 			$reltables = $primary_obj->setRelationTables($secmodule);
 		} else {
 			$reltables = '';
@@ -1632,11 +1632,18 @@ function DeleteEntity($module,$return_module,$focus,$record,$return_id) {
  * Function to related two records of different entity types
   */
 function relateEntities($focus, $sourceModule, $sourceRecordId, $destinationModule, $destinationRecordIds) {
+    $db = PearDatabase::getInstance();
+    $em = new VTEventsManager($db);
+    $data = array('sourceModule'=>$sourceModule, 'sourceRecordId'=>$sourceRecordId,
+                  'destinationModule'=>$destinationModule,'destinationRecordIds'=>$destinationRecordIds);
+    $em->triggerEvent("vtiger.entity.beforerelate", $data);
 	if(!is_array($destinationRecordIds)) $destinationRecordIds = Array($destinationRecordIds);
 	foreach($destinationRecordIds as $destinationRecordId) {
 		$focus->save_related_module($sourceModule, $sourceRecordId, $destinationModule, $destinationRecordId);
 		$focus->trackLinkedInfo($sourceModule, $sourceRecordId, $destinationModule, $destinationRecordId);
 	}
+    
+    $em->triggerEvent("vtiger.entity.afterrelate", $data);
 }
 
 /**
@@ -1755,7 +1762,7 @@ function com_vtGetModules($adb) {
 		inner join vtiger_tab
 			on vtiger_field.tabid=vtiger_tab.tabid
 		where vtiger_field.tabid not in(9,10,16,15,29) and vtiger_tab.presence = 0 and vtiger_tab.isentitytype=1";
-	$it = new SqlResultIterator($adb, $adb->query($sql));
+	$it = new SqlResultIterator($adb, $adb->pquery($sql, array()));
 	$modules = array();
 	foreach($it as $row) {
 		if(isPermitted($row->name,'index') == "yes") {
@@ -1819,7 +1826,8 @@ function getValidDBInsertDateValue($value) {
 function getValidDBInsertDateTimeValue($value) {
 	$value = trim($value);
 	$valueList = explode(' ',$value);
-	if(count($valueList) == 2) {
+    //checking array count = 3 if datatime format is 12hr.
+	if(is_array($valueList) && (count($valueList) == 2 || count($valueList) == 3)) {
 		$dbDateValue = getValidDBInsertDateValue($valueList[0]);
 		$dbTimeValue = $valueList[1];
 		if(!empty($dbTimeValue) && strpos($dbTimeValue, ':') === false) {
@@ -1835,7 +1843,7 @@ function getValidDBInsertDateTimeValue($value) {
 		} catch (Exception $ex) {
 			return '';
 		}
-	} elseif(count($valueList == 1)) {
+	} elseif(is_array($valueList) && count($valueList) == 1) {
 		return getValidDBInsertDateValue($value);
 	}
 }
@@ -2322,33 +2330,6 @@ function lower_array(&$string){
 	$string = strtolower(trim($string));
 }
 
-/* PHP 7 support */
-function php7_compat_split($delim, $str, $ignore_case=false) {
-	$splits = array();
-	while ($str) {
-		$pos = $ignore_case ? stripos($str, $delim) : strpos($str, $delim);
-		if ($pos !== false) {
-			$splits[] = substr($str, 0, $pos);
-			$str = substr($str, $pos + strlen($delim));
-		} else {
-			$splits[] = $str;
-			$str = false;
-		}
-	}
-	return $splits;
-}
-
-if (!function_exists('split'))  { function split($delim, $str)  {return php7_compat_split($delim, $str); } }
-if (!function_exists('spliti')) { function spliti($delim, $str) {return php7_compat_split($delim, $str, true);}}
-
-function php7_compat_ereg($pattern, $str, $ignore_case=false) {
-	$regex = '/'. preg_replace('/\//', '\\/', $pattern) .'/' . ($ignore_case ? 'i': '');
-	return preg_match($regex, $str);
-}
-
-if (!function_exists('ereg')) { function ereg($pattern, $str) { return php7_compat_ereg($pattern, $str); } }
-if (!function_exists('eregi')) { function eregi($pattern, $str) { return php7_compat_ereg($pattern, $str, true); } }
-
 if (!function_exists('get_magic_quotes_runtime')) { function get_magic_quotes_runtime() { return false; } }
 if (!function_exists('set_magic_quotes_runtime')) { function set_magic_quotes_runtime($flag) {} }
 
@@ -2449,7 +2430,7 @@ function getRecordGroupId($record) {
  */
 function deleteRecordFromDetailViewNavigationRecords($recordId, $cvId, $moduleName) {
 	$recordNavigationInfo = Zend_Json::decode($_SESSION[$moduleName . '_DetailView_Navigation' . $cvId]);
-	if (count($recordNavigationInfo) != 0) {
+	if (!empty($recordNavigationInfo) && (count($recordNavigationInfo) != 0)) {
 		foreach ($recordNavigationInfo as $key => $recordIdList) {
 			$recordIdList = array_diff($recordIdList, array($recordId));
 			$recordNavigationInfo[$key] = $recordIdList;
@@ -2620,4 +2601,4 @@ function getDuplicatesPreventionMessage($moduleName, $duplicateRecordsList) {
 	return $message;
 }
 
-?>
\ No newline at end of file
+?>
