@@ -8,9 +8,13 @@ class iCalendar_component {
     var $valid_properties = NULL;
     var $valid_components = NULL;
 
-    function iCalendar_component() {
+    function __construct()
+    {
         $this->construct();
     }
+    function iCalendar_component() {
+        self::__construct();
+    }
 
     function construct() {
         // Initialize the components array
